#!/bin/sh
# ConfigIssue3.sh for use with Issue 3 DRV Video Processor PCBs
# Version 5
# Written by LDD Technology
#
# Description:
#	Kills off any running TriteQPi or TriteQ_Gui apps - these are the only ones ever run in the background.
#	Checks for updated files in the ./update folder and copies existing files to the ./previous folder
#   before moving updates to the working folder. the ./update folder should always be left empty. The priviliges of any 
#   apps are set to allow them to execute.
#   Having completed any updates the main apps are launched in the background.
#   TriteQ_GUI is launched first before TriteQPi so that the comms socket between them binds correctly.
#
# Change Record:
#	Version 1 08/08/2018
#		changed printf to echo in config_crosslink function to neaten printout
#		added extra output to config_crosslink function to show completion when retrying
#	Version 2 05/11/2018
#		fixed system update so that ./update files are copied to the right place and ./update is left empty
#
#	Version 3 28/11/2018
#		removed Crosslink configuration as it is performed by the main app
#
#	Version 4 17/04/2019
#		Added sudo to file accesses so that they will work when running from a command window
#
#	Version 5 19/06/2019
#		added checking for existence of update folder otherwise all files can be moved away from TriteQ folder
#		added checking for and creation of previous folder
#
# ############################ START SCRIPT ###############################
echo "Starting ConfigIssue3.sh Version 5"

# just in case anything is still running
sudo pkill TriteQ
sudo pkill DRV_

# Check whether wired Ethernet is available
if [ -d "/sys/class/net/eth0" ]; then
# This line allows connection using wired ethernet
sudo ifconfig eth0 192.168.0.1 netmask 255.255.255.0
fi

# Change to home directory
cd /home/pi/TriteQ

# Check whether 'previous' folder exists and if not then create it
if ! [ -d "previous" ]; then
	echo "'previous' folder does not exist so creating it"
	mkdir -m 777 previous
fi

# Check whether the 'update' folder exists and if so check for updated file otherwise create the folder
if [ -d "update" ]; then

# check for updated files
cd update 

# look at all files in update folder
FILES=*
for file in $FILES
do
	if [ $file != "*" ]; then
		echo "new $file update detected"
		# if there is an existing version in the working folder copy it to the ../previous folder and delete it
		if [ -f ../$file ]; then
			sudo cp -r -f ../$file ../previous
			sudo rm -r ../$file
		fi
		# copy the new file into the working folder
		sudo cp -r $file ..
		# and remove it from the updates folder
		sudo rm -r $file
	fi
done


# move up to the working folder
cd ..
else
	echo "'update' folder does not exist so creating it"
	mkdir -m 777 update
fi

# ensure apps have execute privileges
if [ -f TriteQPi ]; then 
	sudo chmod 777 TriteQPi
fi
if [ -f TriteQ_Gui ]; then
	sudo chmod 777 TriteQ_Gui
fi
if [ -f CrosslinkProgrammer ]; then
	sudo chmod 777 CrosslinkProgrammer
fi
if [ -f S25FL128 ]; then
	sudo chmod 777 S25FL128
fi

sudo chmod 666 log/gui.log
echo GUI Log > log/gui.log

#launch the GUI in the background
./TriteQ_Gui>>log/gui.log &
sleep 1

# launch the main app in the background
./TriteQPi &


echo "End of ConfigIssue3.sh"
